==> gtk-gnutella_0.95.orig.tar.gz: gtk-gnutella-0.95/src/ui/gtk/search_stats.h <==
/*
 * $Id: search_stats.h,v 1.1 2004/08/24 22:59:18 rmanfredi Exp $
 *
 * Copyright (c) 2001-2003, Richard Eckart
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

#ifndef _gtk_search_stats_h_
#define _gtk_search_stats_h_

#include "common.h"

/*
 * Stats types for search_stats_gui_set_type()
 */
enum {
    NO_SEARCH_STATS,
    WORD_SEARCH_STATS,
    WHOLE_SEARCH_STATS,
    ROUTED_SEARCH_STATS
};

void search_stats_gui_init(void);
void search_stats_gui_shutdown(void);
void search_stats_gui_reset(void);
void search_stats_gui_set_type(gint type);
void search_stats_gui_update(time_t now);

#endif /* _gtk_search_stats_h_ */

==> gtk-gnutella_0.96.4.orig.tar.gz: gtk-gnutella-0.96.4/src/ui/gtk/search_stats.h <==
/*
 * $Id: search_stats.h 8394 2005-06-29 14:24:29Z daichik $
 *
 * Copyright (c) 2001-2003, Richard Eckart
 *
 *----------------------------------------------------------------------
 * This file is part of gtk-gnutella.
 *
 *  gtk-gnutella is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  gtk-gnutella is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gtk-gnutella; if not, write to the Free Software
 *  Foundation, Inc.:
 *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *----------------------------------------------------------------------
 */

#ifndef _gtk_search_stats_h_
#define _gtk_search_stats_h_

#include "common.h"

/**
 * Stats types for search_stats_gui_set_type().
 */
enum {
    NO_SEARCH_STATS,
    WORD_SEARCH_STATS,
    WHOLE_SEARCH_STATS,
    ROUTED_SEARCH_STATS
};

void search_stats_gui_init(void);
void search_stats_gui_shutdown(void);
void search_stats_gui_reset(void);
void search_stats_gui_set_type(gint type);
void search_stats_gui_update(time_t now);

#endif /* _gtk_search_stats_h_ */
